@@ -403,6 +403,8 @@ def toy_significance(**kwargs):
               help='Minimizer type')
 @click.option('--strategy', type=int, default=1, show_default=True,
               help='Default minimization strategy')
+@click.option('--offset/--no-offset', default=True, show_default=True,
+              help='Use NLL offset.')
 @click.option('--print_level', type=int, default=-1, show_default=True,
               help='Minimizer print level')
 @click.option('--verbosity', default="INFO", show_default=True,
