@@ -408,7 +408,7 @@ class AsymptoticCLs(AnalysisObject):
             self.stdout.info('Unresolved fit failures detected')
             for sigma in self.summary:
                 label = self._SIGMA_LABEL_.get(sigma, sigma)
-                self.stdout.info("{}:".format(label).ljust(10), self.summary[sigma].get('status', None))
+                self.stdout.info("{}:".format(label).ljust(10) + str(self.summary[sigma].get('status', None)))
             self.stdout.info('-----------------------------------------------')
 
     def print_summary(self):
