@@ -193,6 +193,19 @@ class Likelihood(AnalysisObject):
         self.model.workspace.saveSnapshot("initialSnapshot", self.model.workspace.allVars())
         self.poi = self.model.get_poi(poi_name)
         
+    def _evaluate(self, poi_val:Optional[float]=None, 
+                  snapshot_name:Optional[str]="initialSnapshot"):
+        if snapshot_name:
+            self.model.workspace.loadSnapshot(snapshot_name)
+        if poi_val is None:
+            self.poi.setConstant(0)
+        else:
+            self.poi.setVal(poi_val)
+            self.poi.setConstant(1)
+        self.minimizer.minimize()
+        
+        return self.minNll
+        
     def evaluate(self, poi_val:float, vmin:float=10., vmax:float=10., 
                  unconditional=False, hesse:bool=False, minos:bool=False, 
                  snapshot_name:Optional[str]="initialSnapshot"):
