@@ -7,6 +7,19 @@ import numpy as np
 import ROOT
 import quickstats
 
+def is_corrupt(f:ROOT.TFile):
+    if f.IsZombie():
+        return True
+    if f.TestBit(ROOT.TFile.kRecovered):
+        return True
+    if f.GetNkeys() == 0:
+        return True
+    return False
+
+def release_tfiles():
+    for f in ROOT.gROOT.GetListOfFiles():
+        f.Close()
+
 def compile_macro(name='RooTwoSidedCBShape'):
     macros_dir = os.path.join(quickstats.macro_path, 'macros')
     macros_path = os.path.join(macros_dir, name + '.cxx')
